<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Großschreibung ignorieren</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Spelling</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SpellcheckerConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Available languages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checked</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>